==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralEnumeratorSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.S_ENUMSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_ENUMSetImpl;
import io.ciera.tool.sql.ooaofooa.value.LiteralEnumerator;
import io.ciera.tool.sql.ooaofooa.value.LiteralEnumeratorSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class LiteralEnumeratorSetImpl extends InstanceSet<LiteralEnumeratorSet,LiteralEnumerator> implements LiteralEnumeratorSet {

    // attributes
    @Override
    public void setEnum_ID( UniqueId ref_Enum_ID ) throws XtumlException {
        for ( LiteralEnumerator literalenumerator : this ) literalenumerator.setEnum_ID( ref_Enum_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralEnumerator literalenumerator : this ) literalenumerator.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setDataTypeNameColumn( int m_dataTypeNameColumn ) throws XtumlException {
        for ( LiteralEnumerator literalenumerator : this ) literalenumerator.setDataTypeNameColumn( m_dataTypeNameColumn );
    }
    @Override
    public void setDataTypeNameLineNumber( int m_dataTypeNameLineNumber ) throws XtumlException {
        for ( LiteralEnumerator literalenumerator : this ) literalenumerator.setDataTypeNameLineNumber( m_dataTypeNameLineNumber );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralEnumerator literalenumerator : this ) valueset.add( literalenumerator.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public S_ENUMSet R824_has_value_S_ENUM() throws XtumlException {
        S_ENUMSet s_enumset = new S_ENUMSetImpl();
        for ( LiteralEnumerator literalenumerator : this ) s_enumset.add( literalenumerator.R824_has_value_S_ENUM() );
        return s_enumset;
    }


    @Override
    public LiteralEnumerator nullElement() {
        return LiteralEnumeratorImpl.EMPTY_LITERALENUMERATOR;
    }

    @Override
    public LiteralEnumeratorSet emptySet() {
      return new LiteralEnumeratorSetImpl();
    }

    @Override
    public LiteralEnumeratorSet value() {
        return this;
    }

    @Override
    public List<LiteralEnumerator> elements() {
        return Arrays.asList(toArray(new LiteralEnumerator[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralEnumeratorSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.S_ENUMSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_ENUMSetImpl;
import io.ciera.tool.sql.ooaofooa.value.LiteralEnumerator;
import io.ciera.tool.sql.ooaofooa.value.LiteralEnumeratorSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LiteralEnumeratorSetImpl extends InstanceSet<LiteralEnumeratorSet,LiteralEnumerator> implements LiteralEnumeratorSet {

    public LiteralEnumeratorSetImpl() {
    }

    public LiteralEnumeratorSetImpl(Comparator<? super LiteralEnumerator> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setEnum_ID( UniqueId ref_Enum_ID ) throws XtumlException {
        for ( LiteralEnumerator literalenumerator : this ) literalenumerator.setEnum_ID( ref_Enum_ID );
    }
    @Override
    public void setDataTypeNameLineNumber( int m_dataTypeNameLineNumber ) throws XtumlException {
        for ( LiteralEnumerator literalenumerator : this ) literalenumerator.setDataTypeNameLineNumber( m_dataTypeNameLineNumber );
    }
    @Override
    public void setDataTypeNameColumn( int m_dataTypeNameColumn ) throws XtumlException {
        for ( LiteralEnumerator literalenumerator : this ) literalenumerator.setDataTypeNameColumn( m_dataTypeNameColumn );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralEnumerator literalenumerator : this ) literalenumerator.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralEnumerator literalenumerator : this ) valueset.add( literalenumerator.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public S_ENUMSet R824_has_value_S_ENUM() throws XtumlException {
        S_ENUMSet s_enumset = new S_ENUMSetImpl();
        for ( LiteralEnumerator literalenumerator : this ) s_enumset.add( literalenumerator.R824_has_value_S_ENUM() );
        return s_enumset;
    }


    @Override
    public LiteralEnumerator nullElement() {
        return LiteralEnumeratorImpl.EMPTY_LITERALENUMERATOR;
    }

    @Override
    public LiteralEnumeratorSet emptySet() {
      return new LiteralEnumeratorSetImpl();
    }

    @Override
    public LiteralEnumeratorSet emptySet(Comparator<? super LiteralEnumerator> comp) {
      return new LiteralEnumeratorSetImpl(comp);
    }

    @Override
    public LiteralEnumeratorSet value() {
        return this;
    }

    @Override
    public List<LiteralEnumerator> elements() {
        return Arrays.asList(toArray(new LiteralEnumerator[0]));
    }

}
